@@ -35,6 +35,9 @@ TwitterButton::TwitterButton(ButtonType buttonType, QString buttonLabel, QGraphi
     m_isPressed = false;
 
     setTypeButton(buttonType);
+
+    if(buttonType == TwitterButton::Expose)
+        connect(this, SIGNAL(released()),SLOT(_emitExposeSignal()));
 }
 
 /*!
@@ -46,7 +49,7 @@ void TwitterButton::mousePressEvent(QGraphicsSceneMouseEvent *event)
         m_isPressed = true;
         emit pressed();
     }
-
+    _pen.setColor(QColor(255,255,255));
     update();
 }
 
@@ -58,13 +61,13 @@ void TwitterButton::mouseReleaseEvent(QGraphicsSceneMouseEvent *event)
     if(!contains(event->pos()))
         return;
 
+    _pen.setColor(QColor(15, 149, 218));
+
     m_isPressed = false;
     update();
 
     if(_url.isEmpty())
         emit released();
-    else
-        emit released(_url);
 }
 
 /*!
@@ -72,10 +75,13 @@ void TwitterButton::mouseReleaseEvent(QGraphicsSceneMouseEvent *event)
  */
 void TwitterButton::mouseMoveEvent(QGraphicsSceneMouseEvent *event)
 {
-    if(contains(event->pos()))
+    if(contains(event->pos())) {
         m_isPressed = true;
-    else
+        _pen.setColor(QColor(255,255,255));
+    } else {
         m_isPressed = false;
+        _pen.setColor(QColor(15, 149, 218));
+    }
 
     update();
 }
@@ -88,18 +94,6 @@ QRectF TwitterButton::boundingRect() const
     return _buttonImage.rect();
 }
 
-/*!
- * \brief Overridden.
- */
-QPainterPath TwitterButton::shape() const
-{
-    QPainterPath path;
-    //path.addRoundedRect(boundingRect(), 28, 28);
-    path.addRect(boundingRect());
-    return path;
-
-}
-
 /*!
  * \brief Overridden.
  * \param painter Painter object.
@@ -114,44 +108,56 @@ void TwitterButton::paint(QPainter *painter, const QStyleOptionGraphicsItem *opt
         painter->setOpacity(0.7);
 
         switch(_buttonType) {
-            case Update:
-                _buttonSelectedImage = QPixmap(":images/resources/buttons/update_pressed.png");
-                break;
             case Expose:
-                _buttonSelectedImage = QPixmap(":images/resources/buttons/expose_pressed.png");
+                _buttonSelectedImage = QPixmap(":images/resources/buttons/expose-pressed.png");
                 break;
             case Logout:
-                _buttonSelectedImage = QPixmap(":images/resources/buttons/logout_pressed.png");
+                _buttonSelectedImage = QPixmap(":images/resources/buttons/logout-pressed.png");
                 break;
             case Generic:
-                _buttonSelectedImage = QPixmap(":images/resources/buttons/generic_pressed.png");
+                _buttonSelectedImage = QPixmap(":images/resources/buttons/generic-pressed.png");
                 break;
             case Retweet:
-                _buttonSelectedImage = QPixmap(":images/resources/buttons/rt_pressed.png");
+                _buttonSelectedImage = QPixmap(":images/resources/buttons/rt-pressed.png");
                 break;
             case Reply:
-                _buttonSelectedImage = QPixmap(":images/resources/buttons/reply_pressed.png");
+                _buttonSelectedImage = QPixmap(":images/resources/buttons/reply-pressed.png");
                 break;
             case GoUrl:
-                _buttonSelectedImage = QPixmap(":images/resources/buttons/go-to-url_pressed.png");
+                _buttonSelectedImage = QPixmap(":images/resources/buttons/go-to-url-pressed.png");
                 break;
             case Delete:
-                _buttonSelectedImage = QPixmap(":images/resources/buttons/delete_pressed.png");
+                _buttonSelectedImage = QPixmap(":images/resources/buttons/delete-pressed.png");
                 break;
             case Back:
                 _buttonSelectedImage = QPixmap(":images/resources/buttons/back-pressed.png");
                 break;
             case Favorite:
-                _buttonSelectedImage = QPixmap(":images/resources/buttons/favorite_pressed.png");
-                break;
             case NoFavorite:
-                _buttonSelectedImage = QPixmap(":images/resources/buttons/no-fave_pressed.png");
+                _buttonSelectedImage = QPixmap(":images/resources/buttons/favorite-pressed.png");
                 break;
             case More:
                 _buttonSelectedImage = QPixmap(":images/resources/buttons/more-pressed.png");
                 break;
+            case Close:
+                _buttonSelectedImage = QPixmap(":images/resources/buttons/close-pressed.png");
+                break;
+            case LoginSettings:
+                _buttonSelectedImage = QPixmap(":images/resources/buttons/settings-pressed.png");
+                break;
+            case GenericDownLeft:
+                _buttonSelectedImage = QPixmap(":images/resources/buttons/down-left-pressed.png");
+                break;
+            case GenericDownRight:
+                _buttonSelectedImage = QPixmap(":images/resources/buttons/down-right-pressed.png");
+                break;
+            case NewAccount:
+                _buttonSelectedImage = QPixmap(":images/resources/buttons/new-account-pressed.png");
+                break;
+            case Refresh:
+                _buttonSelectedImage = QPixmap(":images/resources/buttons/refresh-pressed.png");
+                break;
         }
-
     } else
         _buttonSelectedImage = 0;
 
@@ -179,10 +185,15 @@ void TwitterButton::paint(QPainter *painter, const QStyleOptionGraphicsItem *opt
  */
 void TwitterButton::enable(bool option)
 {
-    if(!option)
+    if(!option) {
         _pen.setColor(QColor(117, 117, 117));
-    else
+        if (_buttonType == LoginSettings)
+            _buttonImage = QPixmap(":images/resources/buttons/settings-disabled.png");
+    } else {
         _pen.setColor(QColor(15, 149, 218));
+        if (_buttonType == LoginSettings)
+            _buttonImage = QPixmap(":images/resources/buttons/settings.png");
+    }
     this->setEnabled(option);
 }
 
@@ -193,9 +204,6 @@ void TwitterButton::enable(bool option)
 void TwitterButton::setTypeButton(int buttonType)
 {
     switch(buttonType){
-        case Update:
-            _buttonImage = QPixmap(":images/resources/buttons/update.png");
-            break;
         case Expose:
             _buttonImage = QPixmap(":images/resources/buttons/expose.png");
             break;
@@ -215,7 +223,7 @@ void TwitterButton::setTypeButton(int buttonType)
             _buttonImage = QPixmap(":images/resources/buttons/favorite.png");
             break;
         case NoFavorite:
-            _buttonImage = QPixmap(":images/resources/buttons/no-fave.png");
+            _buttonImage = QPixmap(":images/resources/buttons/no-favorite.png");
             break;
         case GoUrl:
             _buttonImage = QPixmap(":images/resources/buttons/go-to-url.png");
@@ -226,15 +234,33 @@ void TwitterButton::setTypeButton(int buttonType)
         case Back:
             _buttonImage = QPixmap(":images/resources/buttons/back.png");
             break;
-        case Tab:
-            _buttonImage = QPixmap(":images/resources/buttons/tab.png");
-            break;
         case More:
             _buttonImage = QPixmap(":images/resources/buttons/more.png");
             break;
+        case Close:
+            _buttonImage = QPixmap(":images/resources/buttons/close.png");
+            break;
+        case LoginSettings:
+            _buttonImage = QPixmap(":images/resources/buttons/settings.png");
+            break;
+        case GenericDownLeft:
+            _buttonImage = QPixmap(":images/resources/buttons/down-left.png");
+            break;
+        case GenericDownRight:
+            _buttonImage = QPixmap(":images/resources/buttons/down-right.png");
+            break;
+        case NewAccount:
+            _buttonImage = QPixmap(":images/resources/buttons/new-account.png");
+            break;
+        case Refresh:
+            _buttonImage = QPixmap(":images/resources/buttons/refresh.png");
+            break;
     }
     this->_buttonType = buttonType;
     update();
+    setGeometry(_buttonImage.rect());
+    setMinimumSize(_buttonImage.size());
+    setMaximumSize(_buttonImage.size());
 }
 
 /*!
@@ -247,10 +273,12 @@ void TwitterButton::setLabel(QString label)
 }
 
 /*!
- * \brief This function sets the url in the button.
- * \param response The button's url.
+ * \brief Emits a DBus signal to Hildon Desktop who manages the app window with.
+ * the task swticher when the expose button is pressed.
  */
-void TwitterButton::setUrl(QString url)
+void TwitterButton::_emitExposeSignal()
 {
-    this->_url = url;
+    QDBusConnection bus = QDBusConnection::sessionBus();
+    QDBusMessage message = QDBusMessage::createSignal("/", "com.nokia.hildon_desktop", "exit_app_view");
+    bus.send(message);
 }
