@@ -75,7 +75,7 @@ TwitterTopBar::TwitterTopBar(QGraphicsWidget *parent)
 
     // Add Buttons to List
     _buttonsList->addToList(_homeButton);
-//    _buttonsList->addToList(_mentionsButton);
+    _buttonsList->addToList(_mentionsButton);
 
     // Get user's information from backend
     user = Backend::getInstance()->userInfo();
