@@ -38,15 +38,14 @@ Backend *Backend::getInstance(void)
     return Backend::_instance;
 }
 
-/*! 
+/*!
  * \brief TwitterButton constructor.
  */
 Backend::Backend()
     : twitterapi( new TwitterAPI ),
-    friendsPage(1),
-    isUpdate(false)
+    friendsPage(1)
 {
-        QSettings settings("Zagaia","TweeGo");
+//    QSettings settings("Zagaia","TweeGo");
 //        settings.beginGroup("PROXY");
 //        if(settings.value("useProxy").toBool()) {
 //            m_twitLib->SetProxy(SERVER::HTTP_PROXY, settings.value("ip").toString(),
@@ -56,13 +55,13 @@ Backend::Backend()
 //        }
 //        settings.endGroup();
 
-        twitterapi->setServiceUrl("https://twitter.com");
-        twitterapi->setUsingOAuth(true);
+    twitterapi->setServiceUrl("https://twitter.com");
+    twitterapi->setUsingOAuth(true);
 
-        connect(twitterapi, SIGNAL(credentials(EntryList)), SLOT(_credentials(EntryList)));
-        connect(twitterapi, SIGNAL(newEntries(EntryList)), SLOT(_parseEntries(EntryList)));
-        connect(twitterapi, SIGNAL(deleteEntry(quint64)), SLOT(_deleteEntry(quint64)));
-        connect(twitterapi, SIGNAL(errorMessage(QString)), SLOT(_error(QString)));
+    connect(twitterapi, SIGNAL(credentials(EntryList)), SLOT(_credentials(EntryList)));
+    connect(twitterapi, SIGNAL(newEntries(EntryList)), SLOT(_parseEntries(EntryList)));
+    connect(twitterapi, SIGNAL(deleteEntry(quint64)), SLOT(_deleteEntry(quint64)));
+    connect(twitterapi, SIGNAL(errorMessage(QNetworkReply::NetworkError)), SLOT(_error(QNetworkReply::NetworkError)));
 }
 
 void Backend::_deleteEntry(quint64 id)
@@ -78,17 +77,29 @@ void Backend::_credentials(EntryList entries)
 
 void Backend::_parseEntries(EntryList entries)
 {
+    int lastConn = conns.at(0);
+    conns.removeAt(0);
+
+    switch(lastConn)
+    {
+        case Connection::GetFriendsTimeline:
+            _tweets = entries;
+            emit gotFriendsTimeline();
+            break;
+
+        case Connection::Update:
+            _tweets = entries;
+            emit updatePosted();
+            break;
+    }
+
     foreach( const Entry &entry, entries ) {
         if(entry.isOwn)
             userInformations = entry.userInfo;
     }
 
-    if(!isUpdate)
-        emit entryList(entries);
-    else {
-        emit updatePosted(entries);
-        isUpdate = false;
-    }
+
+
 }
 
 /*!
@@ -97,20 +108,11 @@ void Backend::_parseEntries(EntryList entries)
  */
 void Backend::update(QString status, QString lat, QString lon, quint64 inReplyToStatusId)
 {
+    Q_UNUSED(lat);
+    Q_UNUSED(lon);
+    Q_UNUSED(inReplyToStatusId);
+    conns << Connection::Update;
     twitterapi->postUpdate(status/*,inReplyToStatusId*/);
-    isUpdate = true;
-//    m_isUpdate = true;
-
-//    m_twitLib->PostNewStatus(status, lat, lon, in_reply_to_status_id);
-
-//    if(m_twitLib->head.statusCode() == 200) {
-//        emit updatePosted();
-//        return true;
-//    }
-//    else {
-//        emit updateError("Update Failed. Retry?");
-//        return false;
-//    }
 }
 
 /*!
@@ -127,6 +129,7 @@ void Backend::getTimeline(Timeline::TimelineType type)
             // TODO: implement twitterapi->userTimeline().
             break;
         case Timeline::Friends:
+            conns << Connection::GetFriendsTimeline;
             twitterapi->friendsTimeline(friendsPage);
             friendsPage++;
             break;
@@ -155,6 +158,11 @@ UserInfo Backend::userInfo()
     return userInformations;
 }
 
+EntryList Backend::tweets(void)
+{
+    return _tweets;
+}
+
 /*!
  * \brief Sets which friends timeline page to download.
  * \param page Page number.
@@ -164,52 +172,33 @@ void Backend::setFriendsPage(int page)
     friendsPage = page;
 }
 
-/*!
- * \brief Gets friend's page number that was last downloaded.
- * \return Number of the last page downloaded.
- */
-int Backend::getFriendsPage(void)
-{
-//    return option1->page;
-}
-
 /*!
  * \brief Sets which user timeline page to download.
  * \param page Page number.
  */
 void Backend::setUsersPage(int page)
 {
-//    option2->page = page;
-//    option2->screen_name = userInformations.at(0);
+    userPage = page;
 }
 
-/*!
- * \brief Gets user's page number that was last downloaded.
- * \return Number of the last downloaded page.
- */
-int Backend::getUsersPage(void)
-{
-//    return option2->page;
-}
-
-
 /*!
  * \brief Adds the status(tweet) as favorite.
  * \param id Tweet's id.
- * \param isFavorite String that check if the tweet is already favorite or not.
- * \return True if successful or false otherwise.
  */
-bool Backend::addFavorite(unsigned long long int id, bool isFavorite)
+void Backend::addFavorite(quint64 id)
 {
-//    if(!isFavorite)
-//        m_twitLib->AddFavorite(id);
-//    else
-//        m_twitLib->RemoveFavorite(id);
+    conns << Connection::AddFavorite;
+    twitterapi->createFavorite(id);
+}
 
-//    if(m_twitLib->head.statusCode() == 200)
-//        return true;
-//    else
-//        return false;
+/*!
+ * \brief Remove the status(tweet) as favorite.
+ * \param id Tweet's id.
+ */
+void Backend::removeFavorite(quint64 id)
+{
+    conns << Connection::RemoveFavorite;
+    twitterapi->destroyFavorite(id);
 }
 
 /*!
@@ -218,38 +207,28 @@ bool Backend::addFavorite(unsigned long long int id, bool isFavorite)
  */
 void Backend::removeStatus(quint64 id)
 {
+    conns << Connection::RemoveStatus;
     twitterapi->deleteUpdate(id);
 }
 
 /*!
  * \brief Removes the user from the following list.
- * \param user Username.
- * \return true if successful or false otherwise.
+ * \param id User id.
  */
-bool Backend::removeFriendship(QString user)
+void Backend::removeFriendship(quint64 id)
 {
-//    m_twitLib->RemoveFriendship(user);
-
-//    if(m_twitLib->head.statusCode() == 200)
-//        return true;
-//    else
-//        return false;
+    conns << Connection::RemoveFriendship;
+    twitterapi->unfollow(id);
 }
 
 /*!
  * \brief Adds the user in the following list.
- * \param user Username.
- * \param follow Condition to follow.
- * \return true if successful or false otherwise.
+ * \param id User id.
  */
-bool Backend::addFriendship(QString user)
+void Backend::addFriendship(quint64 id)
 {
-//    m_twitLib->AddFriendship(user,true);
-
-//    if(m_twitLib->head.statusCode() == 200)
-//        return true;
-//    else
-//        return false;
+    conns << Connection::addFriendship;
+    twitterapi->follow(id);
 }
 
 /*!
@@ -258,14 +237,10 @@ bool Backend::addFriendship(QString user)
  * \param text The message.
  * \return true if successful or false otherwise.
  */
-bool Backend::sendDirectMessage(QString user, QString text)
+void Backend::sendDirectMessage(QString user, QString msg)
 {
-//    m_twitLib->SendDirectMessage(user, text);
-
-//    if(m_twitLib->head.statusCode() == 200)
-//        return true;
-//    else
-//        return false;
+    conns << Connection::SendDirectMessage;
+    twitterapi->postDM(user,msg);
 }
 
 /*!
@@ -275,12 +250,9 @@ bool Backend::sendDirectMessage(QString user, QString text)
  */
 bool Backend::updateProfileImage(QString image)
 {
-//    m_twitLib->UpdateProfileImage(image);
-
-//    if(m_twitLib->head.statusCode() == 200)
-//        return true;
-//    else
-//        return false;
+    // TODO: implement on twitterapi :(
+    Q_UNUSED(image);
+    return false;
 }
 
 /*!
@@ -288,10 +260,7 @@ bool Backend::updateProfileImage(QString image)
  */
 void Backend::getMentions()
 {
-//    m_twitLib->GetRecentMentions(option3);
-
-//    if(m_twitLib->head.statusCode() != 200)
-//        emit connectionError("Failed to get mentions. Retry?");
+    // TODO
 }
 
 /*!
@@ -300,9 +269,7 @@ void Backend::getMentions()
  */
 void Backend::setMentionsPage(int page)
 {
-//    option3->page = page;
-
-//    changeListOrder = true;
+    mentionsPage = page;
 }
 
 void Backend::setConsumerKey(const QByteArray &consumerKey)
@@ -330,7 +297,7 @@ void Backend::abort(void)
     twitterapi->abort();
 }
 
-void Backend::_error(QString message)
+void Backend::_error(QNetworkReply::NetworkError error)
 {
-    qDebug() << message;
+    qDebug() << error;
 }
