@@ -80,7 +80,9 @@ void UrlShortener::replyFinished( QNetworkReply * reply )
             break;
     }
 
-    QMaemo5InformationBox::information(NULL, message, QMaemo5InformationBox::DefaultTimeout);
+    #ifdef Q_WS_MAEMO_5
+        QMaemo5InformationBox::information(NULL, message, QMaemo5InformationBox::DefaultTimeout);
+    #endif
 }
 
 /*!
@@ -99,7 +101,9 @@ int UrlShortener::replyStatus( QNetworkReply *reply )
  */
 void UrlShortener::parseUrl(QString message)
 {
-    QMaemo5InformationBox::information(NULL, tr("Shortening Url(s) in tweet"), QMaemo5InformationBox::DefaultTimeout);
+    #ifdef Q_WS_MAEMO_5
+        QMaemo5InformationBox::information(NULL, tr("Shortening Url(s) in tweet"), QMaemo5InformationBox::DefaultTimeout);
+    #endif
 
     list = message.split(" ");
 
